@@ -5,9 +5,9 @@ package Perl::Critic::logicLAB;
 
 use strict;
 use warnings;
-use 5.6.0;
+use 5.006;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 1;
 
@@ -15,13 +15,20 @@ __END__
 
 =pod
 
+=begin markdown
+
+[![CPAN version](https://badge.fury.io/pl/Perl-Critic-logicLAB.svg)](http://badge.fury.io/pl/Perl-Critic-logicLAB)
+[![Dist::Zilla Action](https://github.com/jonasbn/perl-critic-logiclab/actions/workflows/ci.yml/badge.svg)](https://github.com/jonasbn/perl-critic-logiclab/actions/workflows/ci.yml)
+
+=end markdown
+
 =head1 NAME
 
 Perl::Critic::logicLAB - Perl::Critic policies implemented and used by logicLAB
 
 =head1 VERSION
 
-This documentation describes version 0.09
+This documentation describes version 0.10
 
 =head1 SYNOPSIS
 
@@ -39,11 +46,9 @@ benefits:
 
 =item * Policies can be released separately
 
-=item * Policies can be released without association with Perl::Critic::logicLAB
-until their value and correctness has been asserted
+=item * Policies can be released without association with Perl::Critic::logicLAB until their value and correctness has been asserted
 
-=item * You can write a meta-package, listing the policies you want on a policy
-by policy level, using the same schema
+=item * You can write a meta-package, listing the policies you want on a policy by policy level, using the same schema
 
 =back
 
@@ -65,19 +70,31 @@ by policy level, using the same schema
 
 =item * L<Perl::Critic::Policy::logicLAB::ModuleBlacklist|Perl::Critic::Policy::logicLAB::ModuleBlacklist>
 
+=item * L<Perl::Critic::Policy::RegularExpressions::RequireDefault|Perl::Critic::Policy::RegularExpressions::RequireDefault>
+
+=back
+
+=head1 BUGS AND LIMITATIONS
+
+Please report issues via GitHub:
+
+=over
+
+=item * L<GitHub Issues|https://github.com/jonasbn/pcll/issues>
+
 =back
 
 =head1 AUTHOR
 
 =over
 
-=item * Jonas B. Nielsen, jonasbn C<< <jonasbn@cpan.org> >>
+=item * Jonas B., jonasbn C<< <jonasbn@cpan.org> >>
 
 =back
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2010-2014 Jonas B. Nielsen (jonasbn), All Rights Reserved.
+Copyright 2010-2021 Jonas B. (jonasbn), All Rights Reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
